@@ -33,7 +33,7 @@ static char scriptPath[PATH_MAX + 1] = "";
 int tkMacOSXGCEnabled = 0;
 long tkMacOSXMacOSXVersion = 0;
 
-#pragma mark TKApplication(TKInit)
+#pragma mark TKApplication(TKInit) 
 
 #if MAC_OS_X_VERSION_MIN_REQUIRED < 1060
 #define NSTextInputContextKeyboardSelectionDidChangeNotification @"NSTextInputContextKeyboardSelectionDidChangeNotification"
@@ -55,10 +55,6 @@ static void keyboardChanged(CFNotificationCenterRef center, void *observer, CFSt
 - (void)_setupWindowNotifications;
 @end
 
-@interface TKApplication(TKScrlbr)
-- (void)_setupScrollBarNotifications;
-@end
-
 @interface TKApplication(TKMenus)
 - (void)_setupMenus;
 @end
@@ -87,11 +83,9 @@ static void keyboardChanged(CFNotificationCenterRef center, void *observer, CFSt
 #endif
 }
 - (void)_setupEventLoop {
-    _running = 1;
-    if (!_appFlags._hasBeenRun) {
-        _appFlags._hasBeenRun = YES;
-	[self finishLaunching];
-    }
+
+    /*Remove private API calls here.*/
+    [self finishLaunching];
     [self setWindowsNeedUpdate:YES];
 }
 - (void)_setup:(Tcl_Interp *)interp {
@@ -104,7 +98,6 @@ static void keyboardChanged(CFNotificationCenterRef center, void *observer, CFSt
 	    selector:@selector(_postedNotification:) name:nil object:nil];
 #endif
     [self _setupWindowNotifications];
-    [self _setupScrollBarNotifications];
     [self _setupApplicationNotifications];
 }
 - (NSString *)tkFrameworkImagePath:(NSString*)image {
